==> dxgl-src-0.3.2.zip: dxgltest/Resource.h <==
// DXGL
// Copyright (C) 2011 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLTEST                            112
#define IDD_TESTGFX                             113
#define IDD_SYSINFO                             115
#define IDI_DXGL                                116
#define IDI_DXGLSM                              117
#define IDB_DXGLINV                             118
#define IDB_DXGLINV64                           119
#define IDD_TEXSHADER                           121
#define IDC_DXDIAG                              1000
#define IDC_SPINSTAGE                           1000
#define IDC_VIDMODES                            1000
#define IDC_RESIZABLE                           1001
#define IDC_SPINALPHAREF                        1001
#define IDC_DDTYPE                              1002
#define IDC_SPINLINEREPEAT                      1002
#define IDC_TABS                                1002
#define IDC_TESTHEADER                          1002
#define IDC_TEXTUREPREVIEW                      1003
#define IDC_DISPLAY                             1004
#define IDC_TESTLIST                            1004
#define IDC_ALPHABLEND                          1006
#define IDC_BGCOLOR                             1007
#define IDC_WINDOWED                            1008
#define IDC_FULLSCREEN                          1009
#define IDC_APIVER                              1012
#define IDC_SPINAPI                             1013
#define IDC_VSYNC                               1015
#define IDC_BUFFERS                             1017
#define IDC_SPINBACK                            1019
#define IDC_FRAMERATE                           1023
#define IDC_SPINFRAME                           1024
#define IDC_FSAA                                1026
#define IDC_FILTERLABEL                         1027
#define IDC_FILTER                              1028
#define IDC_FSAALABEL                           1029
#define IDC_TEST                                1031
#define IDC_DDVER                               1032
#define IDC_DDEXVER                             1041
#define IDC_D3DVER                              1042
#define IDC_D3D7VER                             1043
#define IDC_D3DREFVER                           1044
#define IDC_D3DRAMPVER                          1045
#define IDC_D3DRMVER                            1046
#define IDC_D3DXOFVER                           1047
#define IDC_FILLSTIPPLELLLABEL                  1047
#define IDC_D3DPMESHVER                         1048
#define IDC_FILLSTIPPLETYPE                     1052
#define IDC_FILLSTIPPLEFILE                     1053
#define IDC_FILLSTIPPLEBROWSE                   1054
#define IDC_FILLSTIPPLEPREVIEW                  1055
#define IDC_LINESTIPPLEREPEAT                   1056
#define IDC_LINESTIPPLEPATTERN                  1057
#define IDC_TEXSTAGE                            1058
#define IDC_TEXCOLORKEY                         1059
#define IDC_SETTEXCOLORKEY                      1060
#define IDC_TEXTURE                             1061
#define IDC_TEXTUREFILE                         1062
#define IDC_TEXTUREBROWSE                       1063
#define IDC_CARG1                               1064
#define IDC_CARG1INV                            1065
#define IDC_CARG1A                              1066
#define IDC_CARG2                               1067
#define IDC_CARG2INV                            1068
#define IDC_CARG2A                              1069
#define IDC_COLOROP                             1070
#define IDC_AARG1                               1071
#define IDC_AARG1INV                            1072
#define IDC_AARG1A                              1073
#define IDC_AARG2                               1074
#define IDC_AARG2INV                            1075
#define IDC_AARG2A                              1076
#define IDC_ALPHAOP                             1077
#define IDC_DIFFUSE                             1080
#define IDC_DIFFUSESELECT                       1081
#define IDC_SPECULAR                            1082
#define IDC_SPECULARSELECT                      1083
#define IDC_FACTOR                              1084
#define IDC_FACTORSELECT                        1085
#define IDC_FOGCOLOR                            1086
#define IDC_FOGCOLORSELECT                      1087
#define IDC_SRCBLEND                            1089
#define IDC_DESTBLEND                           1090
#define IDC_ALPHAREF                            1091
#define IDC_ALPHAFUNC                           1092
#define IDC_ALPHASTIPPLE                        1093
#define IDC_COLORKEY                            1094
#define IDC_COLORKEYBLEND                       1095
#define IDC_VERTEXFOGMODE                       1096
#define IDC_PIXELFOGMODE                        1097
#define IDC_FOGSTART                            1098
#define IDC_FOGEND                              1099
#define IDC_FOGDENSITY                          1100
#define IDC_RANGEBASEDFOG                       1101
#define IDC_BGCOLORSELECT                       1102
#define IDC_ALPHATEST                           1103

==> dxgl-src-0.5.1.zip: dxgltest/Resource.h <==
// DXGL
// Copyright (C) 2011 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDD_DXGLTEST                            112
#define IDD_TESTGFX                             113
#define IDD_SYSINFO                             115
#define IDI_DXGL                                116
#define IDI_DXGLSM                              117
#define IDB_DXGLINV                             118
#define IDB_DXGLINV64                           119
#define IDD_TEXSHADER                           121
#define IDD_VERTEXSHADER                        123
#define IDC_DXDIAG                              1000
#define IDC_SPINSTAGE                           1000
#define IDC_VIDMODES                            1000
#define IDC_LIGHTENABLED                        1001
#define IDC_RESIZABLE                           1001
#define IDC_SPINALPHAREF                        1001
#define IDC_DDTYPE                              1002
#define IDC_SPINDETAIL                          1002
#define IDC_SPINLINEREPEAT                      1002
#define IDC_TABS                                1002
#define IDC_TESTHEADER                          1002
#define IDC_TEXTUREPREVIEW                      1003
#define IDC_DISPLAY                             1004
#define IDC_TESTLIST                            1004
#define IDC_FILLMODE                            1005
#define IDC_ALPHABLEND                          1006
#define IDC_DIFFUSESOURCE                       1006
#define IDC_BGCOLOR                             1007
#define IDC_SHADEMODE                           1008
#define IDC_WINDOWED                            1008
#define IDC_FULLSCREEN                          1009
#define IDC_CULLMODE                            1010
#define IDC_FOGENABLE                           1011
#define IDC_APIVER                              1012
#define IDC_MATDIFFUSESELECT                    1012
#define IDC_MATDIFFUSE                          1013
#define IDC_SPINAPI                             1013
#define IDC_ENABLELIGHT                         1014
#define IDC_ENABLESPECULAR                      1015
#define IDC_VSYNC                               1015
#define IDC_DETAIL                              1016
#define IDC_AMBIENT                             1017
#define IDC_BUFFERS                             1017
#define IDC_SPECULARSOURCE                      1018
#define IDC_SPINBACK                            1019
#define IDC_MATSPECULARSELECT                   1020
#define IDC_MATSPECULAR                         1021
#define IDC_AMBIENTSOURCE                       1022
#define IDC_FRAMERATE                           1023
#define IDC_EMISSIVESOURCE                      1024
#define IDC_SPINFRAME                           1024
#define IDC_FSAA                                1026
#define IDC_FILTERLABEL                         1027
#define IDC_FILTER                              1028
#define IDC_FSAALABEL                           1029
#define IDC_TEST                                1031
#define IDC_DDVER                               1032
#define IDC_DDEXVER                             1041
#define IDC_D3DVER                              1042
#define IDC_D3D7VER                             1043
#define IDC_D3DREFVER                           1044
#define IDC_D3DRAMPVER                          1045
#define IDC_D3DRMVER                            1046
#define IDC_D3DXOFVER                           1047
#define IDC_FILLSTIPPLELLLABEL                  1047
#define IDC_D3DPMESHVER                         1048
#define IDC_FILLSTIPPLETYPE                     1052
#define IDC_FILLSTIPPLEFILE                     1053
#define IDC_FILLSTIPPLEBROWSE                   1054
#define IDC_FILLSTIPPLEPREVIEW                  1055
#define IDC_LINESTIPPLEREPEAT                   1056
#define IDC_LINESTIPPLEPATTERN                  1057
#define IDC_TEXSTAGE                            1058
#define IDC_TEXCOLORKEY                         1059
#define IDC_SETTEXCOLORKEY                      1060
#define IDC_TEXTURE                             1061
#define IDC_TEXTUREFILE                         1062
#define IDC_TEXTUREBROWSE                       1063
#define IDC_CARG1                               1064
#define IDC_CARG1INV                            1065
#define IDC_CARG1A                              1066
#define IDC_CARG2                               1067
#define IDC_CARG2INV                            1068
#define IDC_CARG2A                              1069
#define IDC_COLOROP                             1070
#define IDC_AARG1                               1071
#define IDC_AARG1INV                            1072
#define IDC_AARG1A                              1073
#define IDC_AARG2                               1074
#define IDC_AARG2INV                            1075
#define IDC_AARG2A                              1076
#define IDC_ALPHAOP                             1077
#define IDC_DIFFUSE                             1080
#define IDC_DIFFUSESELECT                       1081
#define IDC_SPECULAR                            1082
#define IDC_SPECULARSELECT                      1083
#define IDC_FACTOR                              1084
#define IDC_FACTORSELECT                        1085
#define IDC_FOGCOLOR                            1086
#define IDC_FOGCOLORSELECT                      1087
#define IDC_SRCBLEND                            1089
#define IDC_DESTBLEND                           1090
#define IDC_ALPHAREF                            1091
#define IDC_ALPHAFUNC                           1092
#define IDC_ALPHASTIPPLE                        1093
#define IDC_COLORKEY                            1094
#define IDC_COLORKEYBLEND                       1095
#define IDC_VERTEXFOGMODE                       1096
#define IDC_PIXELFOGMODE                        1097
#define IDC_FOGSTART                            1098
#define IDC_FOGEND                              1099
#define IDC_FOGDENSITY                          1100
#define IDC_RANGEBASEDFOG                       1101
#define IDC_BGCOLORSELECT                       1102
#define IDC_ALPHATEST                           1103
#define IDC_AMBIENTSELECT                       1104
#define IDC_VERTEXCOLOR                         1106
#define IDC_LOCALVIEWER                         1108
#define IDC_EMISSIVE                            1111
#define IDC_EMISSIVESELECT                      1112
#define IDC_MATAMBIENT                          1114
#define IDC_MATAMBIENTSELECT                    1116
#define IDC_POWER                               1118
#define IDC_LIGHTNUMBER                         1120
#define IDC_SPINLIGHT                           1121
#define IDC_LIGHTTYPE                           1123
#define IDC_LIGHTDIFFUSE                        1126
#define IDC_LIGHTDIFFUSESELECT                  1127
#define IDC_LIGHTSPECULAR                       1129
#define IDC_LIGHTSPECULARSELECT                 1131
#define IDC_LIGHTAMBIENT                        1134
#define IDC_LIGHTAMBIENTSELECT                  1135
#define IDC_LIGHTRANGE                          1137
#define IDC_LIGHTFALLOFF                        1139
#define IDC_LIGHTATTEN0                         1143
#define IDC_LIGHTATTEN1                         1144
#define IDC_LIGHTATTEN2                         1145
#define IDC_LIGHTTHETA                          1147
#define IDC_LIGHTPHI                            1149
